@@ -20,6 +20,7 @@ import sys
 import re
 import logging
 import hashlib
+import json
 
 from lxml import etree
 from lxml.html.soupparser import parse
@@ -63,6 +64,17 @@ CMS_HEAD_BACK_TAG = "{% render_block 'css' %}"
 CMS_BODY_FRONT_TAG = "{% cms_toolbar %}"
 CMS_BODY_BACK_TAG = "{% render_block 'js' %}"
 
+CMS_PAGE_ATTRS_COMMENT = '''
+<!--
+CMS page attribute
+Slug: {% page_attribute "slug" %}
+Changed_date: {% page_attribute "changed_date" %}
+Changed_by: {% page_attribute "changed_by" %}
+-->
+'''
+
+CMS_PAGE_ATTRS_COMMENT_MD5 = hashlib.md5(CMS_PAGE_ATTRS_COMMENT).hexdigest()
+
 class Command(BaseCommand):
 
     help = 'Add placeholder to templates'
@@ -91,6 +103,7 @@ class Command(BaseCommand):
 
                 # start preprocess
                 commentDict = self.findComment(file)
+                commentDict[CMS_PAGE_ATTRS_COMMENT_MD5] = CMS_PAGE_ATTRS_COMMENT
                 # end preprocess
 
                 # start process lxml etree
@@ -106,7 +119,9 @@ class Command(BaseCommand):
                     for tag in tags:
                         self.buildPlaceholder(page, tag, name)
                     
-                    self.addCMSTags(page)
+                    pageData = self.addCMSTags(page)
+                    commentDict[pageData[0]] = pageData[1]
+
                     self.replaceKeyword(page, fileDict)
                     idDict = self.buildImgIdDict(page, name)
 
@@ -258,6 +273,31 @@ class Command(BaseCommand):
             head = tag
         for tag in page.iter(tag='body'):
             body = tag
+        
+        titleContent = None
+        createTitle = True
+        for tag in page.iter(tag='title'):
+            titleContent = tag.text
+            tag.text = "{% page_attribute 'page_title' %}"
+            createTitle = False
+
+        description = None
+        createMetaDescription = True
+        for tag in page.iter(tag='meta'):
+            for name, value in tag.items():
+                if name == 'name' and value == 'description':
+                    description = tag.get('content')
+                    tag.set(
+                        "content", "{% page_attribute 'meta_description' %}")
+                    createMetaDescription = False
+                    
+        data = {
+            "title": titleContent,
+            "description": description,
+        }
+        cmsPageData = ("<!--CMS_PAGE_DATA%sEND_CMS_PAGE_DATA-->" % 
+                       json.dumps(data))
+        dataMd5 = hashlib.md5(cmsPageData).hexdigest()
 
         comment = etree.Element('meta')
         comment.set("name", "comment")
@@ -274,20 +314,39 @@ class Command(BaseCommand):
             head.insert(0, addJ)
             head.insert(0, jq)
             head.insert(0, comment)
-            
-            head[-1].tail = CMS_HEAD_BACK_TAG
-
-            if head.text is None:
-                head.text = ''
-            head.text = CMS_HEAD_FRONT_TAG + \
-                        head.text
+            if createMetaDescription:
+                metaDescription = etree.Element('meta')
+                metaDescription.set("name", "description")
+                metaDescription.set(
+                    "content", "{% page_attribute 'meta_description' %}")
+                head.insert(0, metaDescription)
+            if createTitle:
+                title = etree.Element('title')
+                title.text = "{% page_attribute 'page_title' %}"
+                head.insert(0, title)
         else:
+            if createTitle:
+                title = etree.Element('title')
+                title.text = "{% page_attribute 'page_title' %}"
+                head.append(title)
+            if createMetaDescription:
+                metaDescription = etree.Element('meta')
+                metaDescription.set("name", "description")
+                metaDescription.set(
+                    "content", "{% page_attribute 'meta_description' %}")
+                head.append(metaDescription)
             head.append(comment)
             head.append(jq)
             head.append(addJ)
             
-            head.text = CMS_HEAD_FRONT_TAG + \
-                        head.text + CMS_HEAD_BACK_TAG
+        head[-1].tail = CMS_HEAD_BACK_TAG
+
+        if head.text is None:
+            head.text = ''
+        head.text = CMS_HEAD_FRONT_TAG + \
+                    CMS_PAGE_ATTRS_COMMENT_MD5 + "\n" + \
+                    dataMd5 + \
+                    head.text
 
         if body.getchildren():
             if body[-1].tail is None:
@@ -297,6 +356,8 @@ class Command(BaseCommand):
         else:
             body.text = CMS_BODY_FRONT_TAG + body.text + \
                         CMS_BODY_BACK_TAG
+        
+        return (dataMd5, cmsPageData)
 
     def replaceKeyword(self, page, fileDict):
         for tag in page.iter():
