@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: create_zip.py 9979 2017-05-20 16:33:56Z Lavender $
+# $Id: create_zip.py 10169 2017-08-13 03:48:13Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-05-21 00:33:56 +0800 (週日, 21 五月 2017) $
-# $Revision: 9979 $
+# $Date: 2017-08-13 11:48:13 +0800 (週日, 13 八月 2017) $
+# $Revision: 10169 $
 
 import os
 import logging
@@ -28,6 +28,9 @@ from django.template.loader import get_template
 from Zephyrus.boilerplate.management.commands import (
     TEMPLATES_DIR_PATH, STATIC_DIR_PATH, 
     IMAGES_DIR_PATH, ROOT_DIR_PATH, FIXTURES_DIR_PATH)
+    
+FILE_DIR = os.path.abspath(os.path.join(
+    __file__, '..', '..', '..', 'templates', 'boilerplate'))
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -90,15 +93,24 @@ class Command(BaseCommand):
                 logger.info("Zip " + path)
                 zip.write(path)
                 
-        temp = get_template('boilerplate/py/setup.py')
-        content = temp.render()
-        with open(os.path.join(ROOT_DIR_PATH, 'setup.py'), 'wb') as f:
-            f.write(content.encode('utf8'))
+        # with open(os.path.join(FILE_DIR, 'py', 'setup.py'), 'rb') as f:
+            # content = f.read()
+                
+        # with open(os.path.join(ROOT_DIR_PATH, 'setup.py'), 'wb') as f:
+            # f.write(content.encode('utf8'))
             
-        temp = get_template('boilerplate/txt/README.txt')
-        content = temp.render()
-        with open(os.path.join(ROOT_DIR_PATH, 'README.txt'), 'w') as f:
-            f.write(content.encode('utf8'))
+        # with open(os.path.join(FILE_DIR, 'txt', 'README.txt'), 'rb') as f:
+            # content = f.read()
+            
+        # with open(os.path.join(ROOT_DIR_PATH, 'README.txt'), 'w') as f:
+            # f.write(content.encode('utf8'))
+            
+        shutil.copyfile(
+            os.path.join(FILE_DIR, 'py', 'setup.py'), 
+            os.path.join(ROOT_DIR_PATH, 'setup.py'))
+        shutil.copyfile(
+            os.path.join(FILE_DIR, 'txt', 'README.txt'), 
+            os.path.join(ROOT_DIR_PATH, 'README.txt'))
 
         zip.write('./README.txt')
         logger.info("Zip README.txt")
