@@ -77,7 +77,7 @@ class Command(BaseCommand):
         shutil.copytree(imgPath, IMAGES_DIR_PATH)
         logger.info("Copy images folder to root.")
 
-
+        copyHtml = False
         for root, dirs, files in os.walk(path):
             if 'info.json' in files:
                 jsonPath = os.path.join(root, 'info.json')           
@@ -86,6 +86,18 @@ class Command(BaseCommand):
                 logger.info('Copy %s to root.' % 'info.json')
 
             if "index.html" in files or "Index.html" in files:
+                copyHtml = True
+            else:
+                for f in files:
+                    if f.endswith('.html'):
+                        copyHtml = True
+                        with open('GetTemplate.log', 'a+') as log:
+                            log.write(
+                                ("'%s' not have 'index.html', but have %s\n") % 
+                                (path, f))
+            
+
+            if copyHtml:
                 for fileName in files:
                     filePath = os.path.join(root, fileName)
                     if fileName.endswith('.html'):
@@ -103,5 +115,9 @@ class Command(BaseCommand):
                     shutil.copytree(dirPath, dst)
                     logger.info('Copy %s to static folder.' % dirName)
                 break
+        if not copyHtml:
+            with open('GetTemplate.log', 'a+') as log:
+                log.write(
+                    ("'%s' not have html file\n") % path)
 
         logger.info('-----All OK!-----')
\ No newline at end of file
