@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 9987 2017-05-23 05:26:50Z Lavender $
+# $Id: setup.py 10169 2017-08-13 03:48:13Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-05-23 13:26:50 +0800 (週二, 23 五月 2017) $
-# $Revision: 9987 $ 
+# $Date: 2017-08-13 11:48:13 +0800 (週日, 13 八月 2017) $
+# $Revision: 10169 $ 
 
 import os
 import sys
@@ -93,7 +93,7 @@ def writeSettings(settingsPath, templateDir):
         index = None
                 
         for template in os.listdir(path):
-            if "Fix" in template:
+            if "_user" in template:
                 continue
             if template.lower() == 'index.html':
                 index = template
